@@ -1,5 +1,5 @@
 package Object::RateLimiter;
-$Object::RateLimiter::VERSION = '1.003001';
+$Object::RateLimiter::VERSION = '1.004001';
 use strictures 2;
 
 use Carp 'confess';
@@ -37,10 +37,11 @@ sub clone {
   my ($self, %params) = @_;
   $params{events}  = $self->events  unless defined $params{events};
   $params{seconds} = $self->seconds unless defined $params{seconds};
-  $params{_queue}  = $self->_queue  if $self->_queue;
+  $params{_queue}  = $self->_queue->copy if $self->_queue;
   $self->new(%params);
 }
 
+{ no warnings 'once'; *TO_JSON = *export }
 sub export {
   my ($self) = @_;
   +{
@@ -89,18 +90,15 @@ sub is_expired {
 }
 
 print
-  qq[<avenj> it's not\n],
-  qq[<JCW> What's not what?\n],
-  qq[<Capn_Refsmmat> I always thought that\n],
-  qq[<JCW> Thought what?  :o\n],
-  qq[<Capn_Refsmmat> well, I've always had this vague feeling of\n],
-  qq[<JCW> Heh, you sound like seuss.\n],
-  qq[<Capn_Refsmmat> I'm very by your remark\n]
+  qq[<Gilded> Every girlfriendless introvert is now on a list\n],
+  qq[<c[_]> already was^\n],
+  qq[<Gilded> Well yeah the World of Warcraft subscriber database],
+  qq[ but I meant like a government thing\n]
 unless caller; 1;
 
 =pod
 
-=for Pod::Coverage EVENTS QUEUE SECS
+=for Pod::Coverage EVENTS QUEUE SECS TO_JSON
 
 =head1 NAME
 
@@ -173,6 +171,8 @@ applications).
 
 Constructs a new rate-limiter with a clean event history.
 
+Accepts params as a list or a single HASH.
+
 =head2 clear
 
   $ctrl->clear;
@@ -189,17 +189,6 @@ previous settings.
 The new limiter contains a clone of the event history; the old rate-limiter is
 left untouched.
 
-=head2 export
-
-  my $opts = $ctrl->export;
-  # ... later, perhaps after storing/retrieving ...
-  my $recreated = Object::RateLimiter->new(%$opts);
-
-Exports the current state of the rate-limiter as a reference to a hash; the
-exported hash can be fed to L</new> to recreate the rate-limiter.
-
-This is useful if the rate-limiter's state must be stored persistently. 
-
 =head2 delay
 
   if (my $delay = $ctrl->delay) {
@@ -235,6 +224,17 @@ Returns true if L</clear> was called.
 (You're not required to call C<expire()>, but it can be useful to save a
 little memory.)
 
+=head2 export
+
+  my $opts = $ctrl->export;
+  # ... later, perhaps after storing/retrieving ...
+  my $recreated = Object::RateLimiter->new($opts);
+
+Exports the current state of the rate-limiter as a reference to a hash; the
+exported hash can be fed to L</new> to recreate the rate-limiter.
+
+This is useful if the rate-limiter's state must be stored persistently. 
+
 =head2 is_expired
 
 Returns true if the last seen event is outside of our time window (in other
